
//
// XML storage classes version 1.2
//
// Example1.java
//
// Copyright (c) 2005 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

import de.mfuchs.xmlstorage.XMLDoc;
import de.mfuchs.xmlstorage.XMLPos;

/**
 * Example for writing and reading a XML file.
 * 
 * @author martin
 */
public class Example1
{
	/**
	 * Write exampe XML file.
	 * @throws Exception
	 */
    @Test public void testWrite() throws Exception
    {
        XMLDoc doc = new XMLDoc();
        XMLPos pos = new XMLPos(doc);

         // Zusammenstellen der XML-Struktur im Dokument 'doc'
        pos.create("PARAMS");
          pos.create("TEXT");
            pos.setContent("Testgruppe\nZeile 2", true);
          pos.back(); // </TEXT>

          pos.create("COLOR");
            pos.create("RED");
            pos.setContent("234");
            pos.back(); // </RED>

            pos.create("GREEN");
            pos.setContent("22");
            pos.back(); // </GREEN>

            pos.create("BLUE");
            pos.setContent("33");
            pos.back(); // </BLUE>
          pos.back(); // </COLOR>

          pos.create("FONT");
            pos.create("FONT_FILENAME");
            pos.setContent("Arial.ttf");
            pos.back(); // </FONT_FILENAME>

            pos.create("SIZE");
            pos.setContent("12");
            pos.back(); // </SIZE>
          pos.back(); // </FONT>
        pos.back(); // </PARAMS>

         // Schreiben der XML-Datei
        doc.writeFile("example1.xml");
    }


    /**
     * Read the example file back again.
     * @throws Exception
     */
    @Test public void testRead() throws Exception
    {
        XMLDoc doc = new XMLDoc();

         // Einlesen des XML-Files
        doc.readFile("example1.xml");

        String txt = "";
        String filename = "";

        XMLPos pos = new XMLPos(doc);

        if (pos.goDown("PARAMS")) {
            if (pos.goDown("TEXT")) {
                txt = pos.getContent();
                pos.back();
            }
            pos.back();
        }

         // Abfrage eines Elementinhalts, beispielsweise von FONT_FILENAME
        if (pos.go("PARAMS/FONT/FONT_FILENAME")) {
            filename = pos.getContent();
            pos.back();
        }

         // Ausgabe der ermittelten Werte
        System.out.println("TEXT: " + txt);
        System.out.println("font filename: " + filename);

        assertEquals("Arial.ttf", filename); 
    }


    /**
     * Main function of Example1.
     * @param args unused command line arguments
     */
    public static void main(String[] args)
    {
        Example1 me = new Example1();

        try {
            me.testWrite();
            me.testRead();
        } catch(Exception e) {
            e.printStackTrace();
        }
    }
}
