
//
// XML storage classes version 1.2
//
// Example3.java
//
// Copyright (c) 2005 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
    notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions and the following disclaimer in
    the documentation and/or other materials provided with the
    distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

import de.mfuchs.xmlstorage.XMLDoc;
import de.mfuchs.xmlstorage.XMLInt;
import de.mfuchs.xmlstorage.XMLIntRef;
import de.mfuchs.xmlstorage.XMLPos;


/**
 * Example to use XMLStorage for writing and
 * reading XML files.
 * 
 * @author martin
 */
public class Example3
{
	/**
	 * Write an example XML file to disk.
	 * @throws Exception
	 */
    @Test public void testWrite() throws Exception
    {
        XMLDoc doc = new XMLDoc();
        XMLPos pos = new XMLPos(doc);

         // Zusammenstellen der XML-Struktur im Dokument 'doc'
        pos.create("Y_ACHSE");
          new XMLIntRef(pos, "Stopbits").assign(1);
          pos.put("Parity", "N");
        pos.back();

         // Schreiben der XML-Datei
        doc.writeFile("example3.xml");
    }


    /**
     * Read the example file back again.
     * @throws Exception
     */
    @Test public void testRead() throws Exception
    {
        XMLDoc doc = new XMLDoc();

         // Einlesen des XML-Files
        doc.readFile("example3.xml");

        XMLPos pos = new XMLPos(doc);

        int stopbits = 0;
        String parity = "";

         // Abfrage der Attributwerte des Elements "Y_ACHSE"
        if (pos.go("Y_ACHSE")) {
            stopbits = new XMLInt(pos, "Stopbits").intValue();
            parity = pos.get("Parity");

            pos.back();
        }

         // Ausgabe der ermittelten Werte
        System.out.println("Stopbits: " +  stopbits);
        System.out.println("Parity: " +  parity);

        assertTrue("Stopbits", 1==stopbits); 
        assertEquals("Parity", "N", parity); 
    }


    /**
     * Main function of Example3.
     * @param args unused command line arguments
     */
    public static void main(String[] args)
    {
        Example3 me = new Example3();

        try {
            me.testWrite();
            me.testRead();
        } catch(Exception e) {
            e.printStackTrace();
        }
    }
}
