
//
// XML storage classes version 1.2
//
// XMLTest.java
//
// Copyright (c) 2004, 2005, 2007 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
	notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
	notice, this list of conditions and the following disclaimer in
	the documentation and/or other materials provided with the
	distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

import de.mfuchs.xmlstorage.XMLChildrenFilter;
import de.mfuchs.xmlstorage.XMLDoc;
import de.mfuchs.xmlstorage.XMLInt;
import de.mfuchs.xmlstorage.XMLIntRef;
import de.mfuchs.xmlstorage.XMLNode;
import de.mfuchs.xmlstorage.XMLPos;
import de.mfuchs.xmlstorage.stream.XMLStreamReader;

/*
 * Created on 31.07.2004
 */

/**
 * Examples used as tests for XMLStorage.
 * @author Martin Fuchs
 */
public class XMLTest
{
	/**
	 * Stream test 1 for XMLStorage navigate in XML stream.
	 * @throws Exception
	 */
    @Test public void testStreamingReader() throws Exception
    {
    	String path = "packets.xml";

	    XMLStreamReader reader = new XMLStreamReader(path);

	    reader.goDown("get_packets");

		if (reader.firstChild("packet")) do {
    	    XMLInt dbId = new XMLInt(reader, "db_id");
            System.out.println("db_id: " + dbId.intValue());

    	    int x = reader.getNode().getInt("db_id", 12345).intValue();
            System.out.println("x: " + x);

    	    System.out.println(reader + " \"" + reader.get("name") + "\"");
    	} while(reader.nextSkipOthers("packet"));

    	reader.back();

    	reader.close();
    }


	/**
	 * Test 1 for XMLStorage: navigate in XML data.
	 * @throws Exception
	 */
    @Test public void test1() throws Exception
    {
//    	String path = "poem.xml";
//    	String path = "machines.xml";
    	String path = "packets.xml";

    	XMLDoc doc = new XMLDoc();

    	doc.readFile(path);

    	XMLPos pos = new XMLPos(doc);
    	pos.goDown("get_packets");

		//pos.putSubattrib("options", "hide-inactive", String.valueOf(false));

    	XMLChildrenFilter filter = new XMLChildrenFilter(pos, "packet");

    	for(XMLNode node: filter) {
    	    XMLIntRef dbId = new XMLIntRef(node, "db_id");
    	    //db_id.assign(-999);
            System.out.println("db_id: " + dbId.intValue());

    	    int x = node.getInt("db_id", 12345).intValue();
            System.out.println("x: " + x);

    	    System.out.println(node + " \"" + node.get("name") + "\"");
    	}

    	pos.back();

    	doc.writeFile("out.xml");

    	pos = new XMLPos(doc);

//      if (pos.go("get_packets/packet"))
//      if (pos.go("/get_packets/packet"))
//      if (pos.go("/get_packets/packet[5]"))
        if (pos.go("/get_packets/packet[@db_id=\"7628\"]"))
//      if (pos.go("get_machines/machine[@wsid=\"client2\"]"))
        {

    		pos.back();
    	}
    }


	/**
	 * Write an example XML file.
	 * @throws Exception
	 */
    @Test public void test2Write() throws Exception
    {
        XMLDoc doc = new XMLDoc();
        XMLPos pos = new XMLPos(doc);

         // Zusammenstellen der XML-Struktur im Dokument 'doc'
        pos.create("PARAMS");
          pos.create("TEXT");
            pos.setContent("Testgruppe");
          pos.back(); // </TEXT>

          pos.create("COLOR");
            pos.create("RED");
            pos.setContent("234");
            pos.back(); // </RED>

            pos.create("GREEN");
            pos.setContent("22");
            pos.back(); // </GREEN>

            pos.create("BLUE");
            pos.setContent("33");
            pos.back(); // </BLUE>
          pos.back(); // </COLOR>

          pos.create("FONT");
            pos.create("FONT_FILENAME");
            pos.setContent("Arial.ttf");
            pos.back(); // </FONT_FILENAME>

            pos.create("SIZE");
            pos.setContent("12");
            pos.back(); // </SIZE>
          pos.back(); // </FONT>
        pos.back(); // </PARAMS>

         // Schreiben der XML-Datei
        doc.writeFile("sandra1.xml");
    }

    /**
     * Read back the example file and print some of its content.
     * @throws Exception
     */
    @Test public void test2Read() throws Exception
    {
        XMLDoc doc = new XMLDoc();

         // Einlesen des XML-Files
        doc.readFile("sandra1.xml");

        XMLPos pos = new XMLPos(doc);
        String filename = "";
        int size = 0;

         // Abfrage eines Elementinhalts, beispielsweise von FONT_FILENAME
        if (pos.go("PARAMS/FONT")) {
            if (pos.goDown("FONT_FILENAME")) {
                filename = pos.getContent();
                pos.back();
            }

            if (pos.goDown("SIZE")) {
                size = new XMLInt(pos.getContent()).intValue();
                pos.back();
            }

            pos.back();
        }

         // Ausgabe des ermittelten Werts
        System.out.println("font filename: " + filename);
        System.out.println("font size: " + size);

        assertEquals("Font filename", "Arial.ttf", filename);
        assertEquals("Font size", 12, size);
    }


    /**
     * Test 3 of XMLStorage: write another example file.
     * @throws Exception
     */
    @Test public void test3Write() throws Exception
    {
        XMLDoc doc = new XMLDoc();
        XMLPos pos = new XMLPos(doc);

         // create the XML tree in memory
        pos.create("root");

          pos.create("foo");
            pos.setContent("bar");
          pos.back(); // </foo>

          pos.create("foo2");
            pos.put("attr1", "value1");
            pos.put("attr2", "value2");

            pos.create("foo3");
            pos.setContent("bar2");
            pos.back();
          pos.back();

        pos.back(); // </root>

         // write the XML file
        doc.writeFile("test.xml");
    }


    /**
     * Main function of XMLTest.
     * 
     * @param args unused command lien arguments
     */
    public static void main(String[] args)
    {
        XMLTest me = new XMLTest();

        try {
        	me.testStreamingReader();
            me.test1();

            me.test2Write();
            me.test2Read();

            me.test3Write();
        } catch(Exception e) {
            e.printStackTrace();
        }
    }
}
