
//
// XML storage classes version 1.2
//
// XMLNumber.java
//
// Copyright (c) 2004, 2005, 2007 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
	notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
	notice, this list of conditions and the following disclaimer in
	the documentation and/or other materials provided with the
	distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs.xmlstorage;

import java.math.BigDecimal;

import de.mfuchs.xmlstorage.stream.XMLStreamReader;


/**
 * XMLNumber is the type converter for numeric data in XMLStorage.
 */
public class XMLNumber
{
	public XMLNumber(BigDecimal value)
	{
		_value = value;
	}

	public XMLNumber(final String value)
	{
	    this(value, new BigDecimal(0.));
	}

	public XMLNumber(final String value, BigDecimal def/*=0*/)
	{
		if (value!=null && value.length()>0)
			_value = new BigDecimal(value);
		else
			_value = def;
	}


	public XMLNumber(final AbstractXMLNode node, final String attrName)
	{
	    this(node, attrName, new BigDecimal(0.));
	}

	public XMLNumber(final XMLPos pos, final String attrName)
	{
	    this(pos.cur(), attrName, new BigDecimal(0.));
	}

	public XMLNumber(final XMLPos pos, final String attrName, BigDecimal def/*=0*/)
	{
	    this(pos.cur(), attrName, def);
	}

	public XMLNumber(final XMLStreamReader reader, final String attrName)
	{
	    this(reader.getNode(), attrName, new BigDecimal(0.));
	}

	public XMLNumber(final XMLStreamReader reader, final String attrName, BigDecimal def/*=0*/)
	{
		this(reader.getNode(), attrName, def);
	}


	public XMLNumber(final AbstractXMLNode node, final String attrName, BigDecimal def/*=0*/)
	{
		final String value = node.get(attrName);

		if (value.length() > 0)
			_value = new BigDecimal(value);
		else
			_value = def;
	}

	public BigDecimal bigDecimalValue()
	{
		return _value;
	}

	public String toString()
	{
		return String.valueOf(_value);
	}

	protected BigDecimal _value;
}
