
//
// XML storage classes version 1.2
//
// XMLString.java
//
// Copyright (c) 2004, 2005 Martin Fuchs <martin-fuchs@gmx.net>
//


/*

 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright
	notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
	notice, this list of conditions and the following disclaimer in
	the documentation and/or other materials provided with the
	distribution.

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.

*/

package de.mfuchs.xmlstorage;

import de.mfuchs.xmlstorage.stream.XMLStreamReader;


/**
 * XMLString is used convenient attribute data access in XMLNodes.
 */
public class XMLString
{
	public XMLString(String value)
	{
		_value = value;
	}

	public XMLString(final String value, final String def/*=""*/)
	{
		if (value!=null && value.length()>0)
			_value = value;
		else
			_value = def;
	}


	public XMLString(final AbstractXMLNode node, final String attrName)
	{
	    this(node, attrName, "");
	}

	public XMLString(final XMLPos pos, final String attrName)
	{
	    this(pos.cur(), attrName, "");
	}

	public XMLString(final XMLPos pos, final String attrName, final String def/*=""*/)
	{
	    this(pos.cur(), attrName, def);
	}

	public XMLString(final XMLStreamReader reader, final String attrName)
	{
	    this(reader.getNode(), attrName, "");
	}

	public XMLString(final XMLStreamReader reader, final String attrName, final String def/*=""*/)
	{
	    this(reader.getNode(), attrName, def);
	}

	public XMLString(final AbstractXMLNode node, final String attrName, final String def/*=""*/)
	{
		final String value = node.get(attrName);

		if (value.length() > 0)
			_value = value;
		else
			_value = def;
	}


	public String toString()
	{
		return _value;
	}

	protected String _value;
}
